==> kubernetes-model-1.0.49-sources.jar: io/fabric8/openshift/api/model/DockerBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.List;
import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class DockerBuildStrategyBuilder extends DockerBuildStrategyFluentImpl<DockerBuildStrategyBuilder> implements VisitableBuilder<DockerBuildStrategy,DockerBuildStrategyBuilder>{

     DockerBuildStrategyFluent<?> fluent;
public DockerBuildStrategyBuilder(){
    this(new DockerBuildStrategy());
}
public DockerBuildStrategyBuilder( DockerBuildStrategyFluent<?> fluent ){
    this(fluent, new DockerBuildStrategy());
}
public DockerBuildStrategyBuilder( DockerBuildStrategyFluent<?> fluent , DockerBuildStrategy instance ){
    this.fluent = fluent; fluent.withDockerfilePath(instance.getDockerfilePath()); fluent.withEnv(instance.getEnv()); fluent.withForcePull(instance.getForcePull()); fluent.withFrom(instance.getFrom()); fluent.withNoCache(instance.getNoCache()); fluent.withPullSecret(instance.getPullSecret()); 
}
public DockerBuildStrategyBuilder( DockerBuildStrategy instance ){
    this.fluent = this; this.withDockerfilePath(instance.getDockerfilePath()); this.withEnv(instance.getEnv()); this.withForcePull(instance.getForcePull()); this.withFrom(instance.getFrom()); this.withNoCache(instance.getNoCache()); this.withPullSecret(instance.getPullSecret()); 
}

public EditableDockerBuildStrategy build(){
    EditableDockerBuildStrategy buildable = new EditableDockerBuildStrategy(fluent.getDockerfilePath(),fluent.getEnv(),fluent.isForcePull(),fluent.getFrom(),fluent.isNoCache(),fluent.getPullSecret());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
DockerBuildStrategyBuilder that = (DockerBuildStrategyBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/openshift/api/model/DockerBuildStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.List;
import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class DockerBuildStrategyBuilder extends DockerBuildStrategyFluentImpl<DockerBuildStrategyBuilder> implements VisitableBuilder<DockerBuildStrategy,DockerBuildStrategyBuilder>{

     DockerBuildStrategyFluent<?> fluent;
public DockerBuildStrategyBuilder(){
    this(new DockerBuildStrategy());
}
public DockerBuildStrategyBuilder( DockerBuildStrategyFluent<?> fluent ){
    this(fluent, new DockerBuildStrategy());
}
public DockerBuildStrategyBuilder( DockerBuildStrategyFluent<?> fluent , DockerBuildStrategy instance ){
    this.fluent = fluent; fluent.withDockerfilePath(instance.getDockerfilePath()); fluent.withEnv(instance.getEnv()); fluent.withForcePull(instance.getForcePull()); fluent.withFrom(instance.getFrom()); fluent.withNoCache(instance.getNoCache()); fluent.withPullSecret(instance.getPullSecret()); 
}
public DockerBuildStrategyBuilder( DockerBuildStrategy instance ){
    this.fluent = this; this.withDockerfilePath(instance.getDockerfilePath()); this.withEnv(instance.getEnv()); this.withForcePull(instance.getForcePull()); this.withFrom(instance.getFrom()); this.withNoCache(instance.getNoCache()); this.withPullSecret(instance.getPullSecret()); 
}

public DockerBuildStrategy build(){
    DockerBuildStrategy buildable = new DockerBuildStrategy(fluent.getDockerfilePath(),fluent.getEnv(),fluent.isForcePull(),fluent.getFrom(),fluent.isNoCache(),fluent.getPullSecret());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
DockerBuildStrategyBuilder that = (DockerBuildStrategyBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
